# Webform Datetime 24h

Webform Datetime 24h is a lightweight utility module for Drupal that enforces 24-hour time formatting on Webform `time`, `datetime`, and `webform_time` elements. It allows you to enable this behavior on a per-language basis, making it especially useful for multilingual sites where 12-hour AM/PM formats are not appropriate.

---

## Key Features

- Applies 24-hour time formatting (HH\:mm) to Webform time fields
- Compatible with `webform_jqueryui_datepicker` for consistent localization
- Automatically detects Webform submission forms
- Language-aware: enable 24h format only for selected interface languages
- No changes required to individual Webforms or field widgets

---

## Installation

Install as you would any other contributed Drupal module:

```bash
drush en webform_datetime_24h
```

Make sure the [Webform module](https://www.drupal.org/project/webform) is installed and enabled first.

---

## Configuration

1. Navigate to **Configuration → User Interface → Webform 24h Time Format**\
   Or visit: `/admin/config/user-interface/webform-datetime-24h`

2. A list of all installed languages will be displayed.

3. Enable the 24-hour time format for each language where you want it enforced.

4. Save the configuration.

Once enabled, all Webform submission forms rendered in that interface language will automatically switch to 24-hour time input for time-related fields.

---

## How It Works

- The module uses `hook_form_alter()` to detect Webform submission forms.
- It recursively scans for elements of type `webform_time`, `datetime`, and `time`.
- For `webform_time`, it sets `#time_format` to `H:i` and configures the jQuery timepicker.
- For `datetime` and `time`, it updates the relevant render and widget keys to use HTML5 and 24h formatting.
- Overrides are only applied if the current interface language is enabled in the module settings.

---

## Compatibility

- **Drupal**: 10 and 11
- **Webform**: 6.2.0 and later (tested on 6.3.x)
- Works seamlessly with `webform_jqueryui_datepicker`

---

Developed and maintained by Joseph Olstad. Contributions welcome!

---

## License

GPL-2.0-or-later


